/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2002, 2006 All Rights Reserved.
 * (C) Copyright Webify Solutions, Inc. 2002, 2006 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.fabric.telco.orderfeasibility.context.extractor;

import java.util.logging.Logger;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.fabric.da.util.SdoXPathUtil;
import com.ibm.websphere.fabric.da.util.XPathSearchResult;
import com.ibm.websphere.fabric.telco.util.BpelContextHandler;
import com.ibm.websphere.fabric.telco.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;
import com.ibm.ws.fabric.da.sca.util.SdoUtil;
import commonj.sdo.DataObject;

/**
 * The Service Availability Context Extractor, sets producttype based and state
 * based assertions for ServiceAvailability interface.
 * 
 * @author manoj.puthran
 */
public class ServiceAvailabilityContextExtractorImpl implements
		ContextExtractor {

	private static final Logger logger = Logger
			.getLogger(ServiceAvailabilityContextExtractorImpl.class.getName());

	/**
	 * Default constructor.
	 */
	public ServiceAvailabilityContextExtractorImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	// CHECKSTYLE:OFF
	@SuppressWarnings("unused")
	private ContextExtractor getMyService() {
		return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
	}

	// CHECKSTYLE:ON

	/*
	 * (non-Javadoc)
	 * 
	 * @seecom.ibm.websphere.fabric.da.plugin.ContextExtractor#extractContext(
	 * PendingRequest arg0)
	 */
	public Context extractContext(PendingRequest pendingRequest)
			throws UnexpectedContentException {

		Context context = pendingRequest.getContext();

		// Get the Request from Message Body
		// logger.info("Service Availability messagebody "
		// + SdoUtil.printTree(pendingRequest.getMessageBody()));
		//
		// DataObject checkTechnicalAvailabilityReq = (DataObject) ((Sequence)
		// pendingRequest
		// .getMessageBody().get(0)).getValue(0);
		//
		// DataObject checkTechnicalAvailability = (DataObject)
		// checkTechnicalAvailabilityReq.get(1);

		DataObject requestDataObject = pendingRequest.getFirstBodyElement();
		logger.info("Service Availability messagebody "
				+ SdoUtil.printTree(requestDataObject));

		// Get the ServiceOrder from FeasibilityOrder
		// Set context Property as per the service order item id recieved.
		XPathSearchResult result = SdoXPathUtil.getViaXpath(requestDataObject,
				"//serviceOrder/ServiceOrderItem/Service");
		logger.info("result=" + result);
		DataObject service = (DataObject) result.getValue();
		String serviceOrderItemId = service.getString("Id");
		logger.info("serviceOrderItemId=" + serviceOrderItemId);

		if (StringUtils.isNotBlank(serviceOrderItemId)) {
			TypedValue productTypeAssert = new TypedValue(serviceOrderItemId);
			context.setSelectionProperty(
					IConstants.PROP_ASSERTION_HAS_PROD_TYPE, productTypeAssert);
		}

		// Take the state name captured by Address Extractor
		// and Set context Property as per the state name recieved.
		String stateForAssertion = (String) BpelContextHandler
				.getContextProperties().get(IConstants.STATE_ASSERT_VALUE);
		logger.info("stateForAssertion=" + stateForAssertion);
		if (StringUtils.isNotBlank(stateForAssertion)) {
			TypedValue stateAssert = new TypedValue(stateForAssertion);
			context.setSelectionProperty(IConstants.PROP_ASSERTION_STATE,
					stateAssert);
		}

		TypedValue governanceFabricProjectValue = new TypedValue(
				IConstants.FABRIC_GOVERNANCE);

		context.setSelectionProperty(IConstants.FABRIC_GOVERNANCE_VALUE,
				governanceFabricProjectValue);

		return context;
	}

	/**
	 * String Utils class.
	 * 
	 * @author sanjayp
	 */
	public static final class StringUtils {

		private StringUtils() {
		}

		public static boolean isNotBlank(String str) {
			return str != null && !str.trim().equals("");
		}
	}

}